@@ -86,7 +86,7 @@
 #define KIOWIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KIOWIDGETS_NO_DEPRECATED
-#  define KIOWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54800
+#  define KIOWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55200
 #endif
 #ifdef KIOWIDGETS_NO_DEPRECATED_WARNINGS
 #  define KIOWIDGETS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KIOWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KIOWIDGETS_DEPRECATED_WARNINGS_SINCE KIOWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KIOWIDGETS_DEPRECATED_WARNINGS_SINCE 0x54800
+#    define KIOWIDGETS_DEPRECATED_WARNINGS_SINCE 0x55200
 #  endif
 #endif
 
@@ -205,9 +205,46 @@
 #else
 #  define KIOWIDGETS_DEPRECATED_VERSION_5_71(text)
 #endif
+
+#if KIOWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x54b00
+#  define KIOWIDGETS_DEPRECATED_VERSION_5_75(text) KIOWIDGETS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOWIDGETS_DEPRECATED_VERSION_5_75(text)
+#endif
+
+#if KIOWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x54c00
+#  define KIOWIDGETS_DEPRECATED_VERSION_5_76(text) KIOWIDGETS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOWIDGETS_DEPRECATED_VERSION_5_76(text)
+#endif
+
+#if KIOWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x54f00
+#  define KIOWIDGETS_DEPRECATED_VERSION_5_79(text) KIOWIDGETS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOWIDGETS_DEPRECATED_VERSION_5_79(text)
+#endif
+
+#if KIOWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x55000
+#  define KIOWIDGETS_DEPRECATED_VERSION_5_80(text) KIOWIDGETS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOWIDGETS_DEPRECATED_VERSION_5_80(text)
+#endif
+
+#if KIOWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x55200
+#  define KIOWIDGETS_DEPRECATED_VERSION_5_82(text) KIOWIDGETS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOWIDGETS_DEPRECATED_VERSION_5_82(text)
+#endif
 #define KIOWIDGETS_DEPRECATED_VERSION_4(minor, text)      KIOWIDGETS_DEPRECATED_VERSION_4_##minor(text)
 #define KIOWIDGETS_DEPRECATED_VERSION_5(minor, text)      KIOWIDGETS_DEPRECATED_VERSION_5_##minor(text)
 #define KIOWIDGETS_DEPRECATED_VERSION(major, minor, text) KIOWIDGETS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KIOWIDGETS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KIOWIDGETS_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
+#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
+#  define KIOWIDGETS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KIOWIDGETS_DEPRECATED_VERSION(major, minor, text)
+#  define KIOWIDGETS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KIOWIDGETS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#else
+#  define KIOWIDGETS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
+#  define KIOWIDGETS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#endif
 
 #endif /* KIOWIDGETS_EXPORT_H */
